==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/LetterCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Letter;
import microsoft.dynamics.crm.entity.request.ActioncardRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.LetterRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class LetterCollectionRequest extends CollectionPageEntityRequest<Letter, LetterRequest>{

    protected ContextPath contextPath;

    public LetterCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Letter.class, cp -> new LetterRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public ActioncardCollectionRequest letter_actioncard() {
        return new ActioncardCollectionRequest(contextPath.addSegment("letter_actioncard"), Optional.empty());
    }

    public ActioncardRequest letter_actioncard(String actioncardid) {
        return new ActioncardRequest(contextPath.addSegment("letter_actioncard").addKeys(new NameValue(actioncardid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest letter_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("letter_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest letter_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("letter_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_letter() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_letter"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_letter(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_letter").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest letter_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("Letter_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest letter_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("Letter_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest letter_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("letter_connections2"), Optional.empty());
    }

    public ConnectionRequest letter_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("letter_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest letter_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Letter_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest letter_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Letter_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest letter_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("Letter_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest letter_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Letter_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest letter_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("Letter_Annotation"), Optional.empty());
    }

    public AnnotationRequest letter_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("Letter_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest letter_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("letter_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest letter_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("letter_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest letter_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Letter_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest letter_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Letter_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest letter_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("letter_connections1"), Optional.empty());
    }

    public ConnectionRequest letter_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("letter_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest letter_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Letter_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest letter_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Letter_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest letter_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("Letter_QueueItem"), Optional.empty());
    }

    public QueueitemRequest letter_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("Letter_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest letter_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Letter_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest letter_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Letter_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/LetterCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Letter;
import microsoft.dynamics.crm.entity.request.ActioncardRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.AnnotationRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.LetterRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class LetterCollectionRequest extends CollectionPageEntityRequest<Letter, LetterRequest>{

    protected ContextPath contextPath;

    public LetterCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Letter.class, cp -> new LetterRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public ActioncardCollectionRequest letter_actioncard() {
        return new ActioncardCollectionRequest(contextPath.addSegment("letter_actioncard"), Optional.empty());
    }

    public ActioncardRequest letter_actioncard(String actioncardid) {
        return new ActioncardRequest(contextPath.addSegment("letter_actioncard").addKeys(new NameValue(actioncardid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest letter_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("letter_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest letter_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("letter_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_letter() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_letter"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_letter(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_letter").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest letter_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("Letter_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest letter_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("Letter_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest letter_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("letter_connections2"), Optional.empty());
    }

    public ConnectionRequest letter_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("letter_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest letter_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("Letter_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest letter_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("Letter_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest letter_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("Letter_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest letter_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("Letter_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AnnotationCollectionRequest letter_Annotation() {
        return new AnnotationCollectionRequest(contextPath.addSegment("Letter_Annotation"), Optional.empty());
    }

    public AnnotationRequest letter_Annotation(String annotationid) {
        return new AnnotationRequest(contextPath.addSegment("Letter_Annotation").addKeys(new NameValue(annotationid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest letter_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("letter_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest letter_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("letter_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest letter_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("Letter_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest letter_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("Letter_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest letter_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("letter_connections1"), Optional.empty());
    }

    public ConnectionRequest letter_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("letter_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest letter_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Letter_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest letter_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Letter_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest letter_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("Letter_QueueItem"), Optional.empty());
    }

    public QueueitemRequest letter_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("Letter_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest letter_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("Letter_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest letter_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("Letter_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

}
